@@ -55,6 +55,11 @@ type Namespace struct {
 	Ns osprojectv1.Project
 }
 
+//UID get the UID of a namespace
+func (ns *Namespace) UID() string {
+	return string(ns.Ns.UID)
+}
+
 //Name get the name of a namespace
 func (ns *Namespace) Name() string {
 	return ns.Ns.Name
@@ -84,7 +89,6 @@ func (c *DefaultOpenShiftClient) ListNamespaces(token string) (namespaces []Name
 	if err != nil {
 		return nil, err
 	}
-	log.Debugf("Fetched projects: %v", projects)
 	for _, ns := range projects.Items {
 		namespaces = append(namespaces, Namespace{ns})
 	}
